@@ -1,13 +1,15 @@
 from molgraph.chemistry.molecular_encoders import MolecularGraphEncoder
 from molgraph.chemistry.molecular_encoders import MolecularGraphEncoder3D
+from molgraph.chemistry.atomic.featurizers import AtomicFeaturizer
+from molgraph.chemistry.atomic.tokenizers import AtomicTokenizer
+from molgraph.chemistry.conformer_generator import ConformerGenerator
+
 from molgraph.chemistry.atomic.featurizers import AtomFeaturizer
 from molgraph.chemistry.atomic.featurizers import BondFeaturizer
 from molgraph.chemistry.atomic.tokenizers import AtomTokenizer
 from molgraph.chemistry.atomic.tokenizers import BondTokenizer
-from molgraph.chemistry.conformer_generator import ConformerGenerator
 
-from molgraph.chemistry.transform_ops import molecule_from_string
-from molgraph.chemistry.transform_ops import molecule_to_image
+from molgraph.chemistry.ops import molecule_from_string
 from molgraph.chemistry.atomic import features
 from molgraph.chemistry.atomic.features import AtomicFeature
 from molgraph.chemistry.atomic.features import atom_features
